@@ -1,10 +1,11 @@
 ## RH 2019-09-28
 
 #### SETUP ####
-if(!at_home()) exit_file("skipping")
+# not needed:
+# if(!at_home()) exit_file("skipping")
 source("setup_ctrdata.R")
 
-if (!check_internet()) exit_file("Not available: internet connectivity")
+if (!check_internet()) exit_file("Reason: no internet connectivity")
 
 #### active substance ####
 
@@ -14,6 +15,5 @@ tmp_test <- ctrFindActiveSubstanceSynonyms(activesubstance = "imatinib")
 # test
 expect_true(all(c(
   "imatinib", "gleevec", "sti 571", "glivec", "CGP 57148", "st1571")
-  %in% tmp_test),
-  info = "ctrdata_euctr.R#16")
+  %in% tmp_test))
 
