@@ -1,12 +1,12 @@
 ## RH 2019-09-28
 
 #### SETUP ####
-if(!at_home()) exit_file("skipping")
+if(!at_home()) exit_file("Reason: not at_home")
 source("setup_ctrdata.R")
 
-if (!check_mongo_remote_rw()) exit_file("Not available: remote rw MongoDB")
-if (!check_internet())        exit_file("Not available: internet connectivity")
-if (!check_binaries())        exit_file("Not available: php or sed or perl")
+if (!check_mongo_remote_rw()) exit_file("Reason: no remote rw MongoDB")
+if (!check_internet())        exit_file("Reason: no internet connectivity")
+if (!check_binaries())        exit_file("Reason: no binaries php or sed or perl")
 
 # create database object
 dbc <- nodbi::src_mongo(
